/****************************************************************************
 *
 * Filename:    ps5000Api.h
 * Copyright:   Pico Technology Limited 2002 - 2007
 * Author:      MAS
 * Description:
 *
 * This header defines the interface to driver routines for the 
 *	PicoScope5000 range of PC Oscilloscopes.
 *
 ****************************************************************************/
#ifndef __PS5000AAPI_H__
#define __PS5000AAPI_H__

#include "picoStatus.h"

#ifdef PREF0
  #undef PREF0
#endif
#ifdef PREF1
  #undef PREF1
#endif
#ifdef PREF2
  #undef PREF2
#endif
#ifdef PREF3
  #undef PREF3
#endif

#ifdef __cplusplus
	#define PREF0 extern "C"
#else
	#define PREF0
#endif

#ifdef WIN32
/*	If you are dynamically linking PS5000.DLL into your project #define DYNLINK here
 */	
typedef unsigned __int64 u_int64_t;

#ifdef DYNLINK
  #define PREF1 typedef
	#define PREF2
	#define PREF3(x) (__stdcall *x)
#else
  #define PREF1
	#ifdef _USRDLL
		#define PREF2 __declspec(dllexport) __stdcall
	#else
		#define PREF2 __declspec(dllimport) __stdcall
	#endif
  #define PREF3(x) x
#endif
	#define PREF4 __stdcall
#else

	/* Define a 64-bit integer type */
	#include <stdint.h>
	typedef int64_t __int64;

	#ifdef DYNLINK
		#define PREF1 typedef
		#define PREF2
		#define PREF3(x) (*x)
	#else
		#ifdef _USRDLL
			#define PREF1 __attribute__((visibility("default")))
		#else
			#define PREF1
		#endif
		#define PREF2
		#define PREF3(x) x
	#endif
	#define PREF4
#endif

#define PS5000A_MAX_VALUE_8BIT   32512
#define PS5000A_MIN_VALUE_8BIT  -32512

#define PS5000A_MAX_VALUE_16BIT  32767
#define PS5000A_MIN_VALUE_16BIT -32767
#define PS5000A_LOST_DATA -32768

#define PS5000A_EXT_MAX_VALUE  32767
#define PS5000A_EXT_MIN_VALUE -32767

#define MAX_PULSE_WIDTH_QUALIFIER_COUNT 16777215L
#define MAX_DELAY_COUNT 8388607L

// covers the 5242A/B and 5442A/B
#define PS5X42A_MAX_SIG_GEN_BUFFER_SIZE 16384
// covers the 5243A/B and 5443A/B
#define PS5X43A_MAX_SIG_GEN_BUFFER_SIZE 32768
// covers the 5244A/B and 5444A/B
#define PS5X44A_MAX_SIG_GEN_BUFFER_SIZE 49512

#define MIN_SIG_GEN_BUFFER_SIZE 10
#define MIN_DWELL_COUNT				10
#define MAX_SWEEPS_SHOTS				((1 << 30) - 1)


#define MAX_ANALOGUE_OFFSET_50MV_200MV	 0.250f
#define MIN_ANALOGUE_OFFSET_50MV_200MV	-0.250f
#define MAX_ANALOGUE_OFFSET_500MV_2V		 2.500f
#define MIN_ANALOGUE_OFFSET_500MV_2V		-2.500f
#define MAX_ANALOGUE_OFFSET_5V_20V			 20.f
#define MIN_ANALOGUE_OFFSET_5V_20V			-20.f

#define PS5244A_MAX_ETS_CYCLES 500		// PS5242A, PS5242B, PS5442A, PS5442B
#define PS5244A_MAX_ETS_INTERLEAVE 40

#define PS5243A_MAX_ETS_CYCLES 250		// PS5243A, PS5243B, PS5443A, PS5443B
#define PS5243A_MAX_ETS_INTERLEAVE 20

#define PS5242A_MAX_ETS_CYCLES 125    // PS5242A, PS5242B, PS5442A, PS5442B
#define PS5242A_MAX_ETS_INTERLEAVE 10

typedef enum enPS5000ADeviceResolution
{
	PS5000A_DR_8BIT,
	PS5000A_DR_12BIT,
	PS5000A_DR_14BIT,
	PS5000A_DR_15BIT,
	PS5000A_DR_16BIT
} PS5000A_DEVICE_RESOLUTION;

typedef enum enPS5000AExtraOperations
{
	PS5000A_ES_OFF,
	PS5000A_WHITENOISE,
	PS5000A_PRBS // Pseudo-Random Bit Stream 
} PS5000A_EXTRA_OPERATIONS;

typedef enum	enPS5000ABandwidthLimiter
{
	PS5000A_BW_FULL,
	PS5000A_BW_20MHZ,
} PS5000A_BANDWIDTH_LIMITER;

typedef enum enPS5000ACoupling
{
	PS5000A_AC,
	PS5000A_DC
} PS5000A_COUPLING;

typedef enum enPS5000AChannel
{
	PS5000A_CHANNEL_A,
	PS5000A_CHANNEL_B,
	PS5000A_CHANNEL_C,
	PS5000A_CHANNEL_D,
	PS5000A_EXTERNAL,	
	PS5000A_MAX_CHANNELS = PS5000A_EXTERNAL,
	PS5000A_TRIGGER_AUX,
	PS5000A_MAX_TRIGGER_SOURCES
}	PS5000A_CHANNEL;

typedef enum enPS5000AChannelBufferIndex
{
	PS5000A_CHANNEL_A_MAX,
	PS5000A_CHANNEL_A_MIN,
	PS5000A_CHANNEL_B_MAX,
	PS5000A_CHANNEL_B_MIN,
	PS5000A_CHANNEL_C_MAX,
	PS5000A_CHANNEL_C_MIN,
	PS5000A_CHANNEL_D_MAX,
	PS5000A_CHANNEL_D_MIN,
	PS5000A_MAX_CHANNEL_BUFFERS
} PS5000A_CHANNEL_BUFFER_INDEX;

typedef enum enPS5000ARange
{
	PS5000A_10MV,
	PS5000A_20MV,
	PS5000A_50MV,
	PS5000A_100MV,
	PS5000A_200MV,
	PS5000A_500MV,
	PS5000A_1V,
	PS5000A_2V,
	PS5000A_5V,
	PS5000A_10V,
	PS5000A_20V,
	PS5000A_50V,
	PS5000A_MAX_RANGES
}	PS5000A_RANGE;


typedef enum enPS5000AEtsMode
  {
  PS5000A_ETS_OFF,             // ETS disabled
  PS5000A_ETS_FAST,            // Return ready as soon as requested no of interleaves is available
  PS5000A_ETS_SLOW,            // Return ready every time a new set of no_of_cycles is collected
  PS5000A_ETS_MODES_MAX
  }	PS5000A_ETS_MODE;

typedef enum enPS5000ATimeUnits
  {
  PS5000A_FS,
  PS5000A_PS,
  PS5000A_NS,
  PS5000A_US,
  PS5000A_MS,
  PS5000A_S,
  PS5000A_MAX_TIME_UNITS,
  }	PS5000A_TIME_UNITS;

typedef enum enPS5000ASweepType
{
	PS5000A_UP,
	PS5000A_DOWN,
	PS5000A_UPDOWN,
	PS5000A_DOWNUP,
	PS5000A_MAX_SWEEP_TYPES
} PS5000A_SWEEP_TYPE;

typedef enum enPS5000AWaveType
{
	PS5000A_SINE,
	PS5000A_SQUARE,
	PS5000A_TRIANGLE,
	PS5000A_RAMP_UP,
	PS5000A_RAMP_DOWN,
	PS5000A_SINC,
	PS5000A_GAUSSIAN,
	PS5000A_HALF_SINE,
	PS5000A_DC_VOLTAGE,
	PS5000A_WHITE_NOISE,
	PS5000A_MAX_WAVE_TYPES
} PS5000A_WAVE_TYPE;

#define PS5000A_SINE_MAX_FREQUENCY				20000000.f
#define PS5000A_SQUARE_MAX_FREQUENCY			20000000.f
#define PS5000A_TRIANGLE_MAX_FREQUENCY		20000000.f
#define PS5000A_SINC_MAX_FREQUENCY				20000000.f
#define PS5000A_RAMP_MAX_FREQUENCY				20000000.f
#define PS5000A_HALF_SINE_MAX_FREQUENCY	20000000.f
#define PS5000A_GAUSSIAN_MAX_FREQUENCY		20000000.f
#define PS5000A_MIN_FREQUENCY									 0.03f

typedef enum enPS5000ASigGenTrigType
{
	PS5000A_SIGGEN_RISING,
	PS5000A_SIGGEN_FALLING,
	PS5000A_SIGGEN_GATE_HIGH,
	PS5000A_SIGGEN_GATE_LOW
} PS5000A_SIGGEN_TRIG_TYPE;

typedef enum enPS5000ASigGenTrigSource
{
	PS5000A_SIGGEN_NONE,
	PS5000A_SIGGEN_SCOPE_TRIG,
	PS5000A_SIGGEN_AUX_IN,
	PS5000A_SIGGEN_EXT_IN,
	PS5000A_SIGGEN_SOFT_TRIG
} PS5000A_SIGGEN_TRIG_SOURCE;

typedef enum enPS5000AIndexMode
{
	PS5000A_SINGLE,
	PS5000A_DUAL,
	PS5000A_QUAD,
	PS5000A_MAX_INDEX_MODES
} PS5000A_INDEX_MODE;

typedef enum enPS5000AThresholdMode
{
	PS5000A_LEVEL,
	PS5000A_WINDOW
} PS5000A_THRESHOLD_MODE;

typedef enum enPS5000AThresholdDirection
{
	PS5000A_ABOVE, //using upper threshold
	PS5000A_BELOW, 
	PS5000A_RISING, // using upper threshold
	PS5000A_FALLING, // using upper threshold
	PS5000A_RISING_OR_FALLING, // using both threshold
	PS5000A_ABOVE_LOWER, // using lower threshold
	PS5000A_BELOW_LOWER, // using lower threshold
	PS5000A_RISING_LOWER,			 // using upper threshold
	PS5000A_FALLING_LOWER,		 // using upper threshold

	// Windowing using both thresholds
	PS5000A_INSIDE = PS5000A_ABOVE, 
	PS5000A_OUTSIDE = PS5000A_BELOW,
	PS5000A_ENTER = PS5000A_RISING, 
	PS5000A_EXIT = PS5000A_FALLING, 
	PS5000A_ENTER_OR_EXIT = PS5000A_RISING_OR_FALLING,
	PS5000A_POSITIVE_RUNT = 9,
  PS5000A_NEGATIVE_RUNT,

	// no trigger set
  PS5000A_NONE = PS5000A_RISING 
} PS5000A_THRESHOLD_DIRECTION;


typedef enum enPS5000ATriggerState
{
  PS5000A_CONDITION_DONT_CARE,
  PS5000A_CONDITION_TRUE,
  PS5000A_CONDITION_FALSE,
	PS5000A_CONDITION_MAX
} PS5000A_TRIGGER_STATE;
	
#pragma pack(1)
typedef struct tPS5000ATriggerConditions
{
  PS5000A_TRIGGER_STATE channelA;
  PS5000A_TRIGGER_STATE channelB;
  PS5000A_TRIGGER_STATE channelC;
  PS5000A_TRIGGER_STATE channelD;
  PS5000A_TRIGGER_STATE external;
  PS5000A_TRIGGER_STATE aux;
	PS5000A_TRIGGER_STATE pulseWidthQualifier;
} PS5000A_TRIGGER_CONDITIONS;
#pragma pack()

#pragma pack(1)
typedef struct tPS5000APwqConditions
{
  PS5000A_TRIGGER_STATE channelA;
  PS5000A_TRIGGER_STATE channelB;
  PS5000A_TRIGGER_STATE channelC;
  PS5000A_TRIGGER_STATE channelD;
  PS5000A_TRIGGER_STATE external;
  PS5000A_TRIGGER_STATE aux;
} PS5000A_PWQ_CONDITIONS;
#pragma pack()


#pragma pack(1)
typedef struct tPS5000ATriggerChannelProperties
{
  short										thresholdUpper;
	unsigned short					thresholdUpperHysteresis; 
  short										thresholdLower;
	unsigned short					thresholdLowerHysteresis;
	PS5000A_CHANNEL					channel;
  PS5000A_THRESHOLD_MODE	thresholdMode;
} PS5000A_TRIGGER_CHANNEL_PROPERTIES;
#pragma pack()

	
typedef enum enPS5000ARatioMode
{
	PS5000A_RATIO_MODE_NONE = 0,
	PS5000A_RATIO_MODE_AGGREGATE = 1,
	PS5000A_RATIO_MODE_DECIMATE = 2,
	PS5000A_RATIO_MODE_AVERAGE = 4,
	PS5000A_RATIO_MODE_DISTRIBUTION = 8
} PS5000A_RATIO_MODE;

typedef enum enPS5000APulseWidthType
{
	PS5000A_PW_TYPE_NONE,
  PS5000A_PW_TYPE_LESS_THAN,
	PS5000A_PW_TYPE_GREATER_THAN,
	PS5000A_PW_TYPE_IN_RANGE,
	PS5000A_PW_TYPE_OUT_OF_RANGE
} PS5000A_PULSE_WIDTH_TYPE;

typedef enum enPS5000AChannelInfo
{
	PS5000A_CI_RANGES,
} PS5000A_CHANNEL_INFO;

typedef void (PREF4 *ps5000aBlockReady)
	(
		short											handle,
		PICO_STATUS								status,
		void										*	pParameter
	); 

typedef void (PREF4 *ps5000aStreamingReady)
	(
		short    									handle,
		long     									noOfSamples,
		unsigned long							startIndex,
		short    									overflow,
		unsigned long							triggerAt,
		short    									triggered,
		short    									autoStop,
		void										*	pParameter
	); 

// see if this is actually used
typedef void (__stdcall *ps5000aDataReady)
	(
		short    									handle,
		PICO_STATUS								status,
		unsigned long     				noOfSamples,
		short    									overflow,
		void										*	pParameter
	); 

PREF0 PREF1 PICO_STATUS PREF2 PREF3 (ps5000aOpenUnit) 
  (
	  short											* handle,
		char											* serial,
		PS5000A_DEVICE_RESOLUTION		resolution		
	);

PREF0 PREF1 PICO_STATUS PREF2 PREF3 (ps5000aOpenUnitAsync)
  (
	  short											* status,
		char											* serial,
		PS5000A_DEVICE_RESOLUTION		resolution
	);

PREF0 PREF1 PICO_STATUS PREF2 PREF3 (ps5000aOpenUnitProgress)
	(
	  short 										* handle,
	  short 										* progressPercent,
	  short 										* complete
	); 

PREF0 PREF1 PICO_STATUS PREF2 PREF3 (ps5000aGetUnitInfo)
 	(
	  short     								  handle, 
	  char      								* string,
	  short     								  stringLength,
	  short     								* requiredSize,
	  PICO_INFO 								  info
	);

PREF0 PREF1 PICO_STATUS PREF2 PREF3 (ps5000aFlashLed)
	(
	  short 											handle,
		short 											start
	);

PREF0 PREF1 PICO_STATUS PREF2 PREF3 (ps5000aIsLedFlashing)
	(
	  short 										  handle,
		short 										* status
	);

PREF0 PREF1 PICO_STATUS PREF2 PREF3 (ps5000aCloseUnit)
	(
	  short												handle
	);

PREF0 PREF1 PICO_STATUS PREF2 PREF3 (ps5000aMemorySegments)
	(
	  short												handle,
		unsigned long								nSegments,
		long											* nMaxSamples
	);


PREF0 PREF1 PICO_STATUS PREF2 PREF3 (ps5000aSetChannel)
 	(
	  short											handle,
		PS5000A_CHANNEL						channel,
	  short											enabled,
	  PS5000A_COUPLING					type, 
		PS5000A_RANGE							range,
		float											analogOffset
	);


PREF0 PREF1 PICO_STATUS PREF2 PREF3 (ps5000aSetBandwidthFilter)
 	(
	  short												handle,
	  PS5000A_CHANNEL							channel,
	  PS5000A_BANDWIDTH_LIMITER		bandwidth
	);


PREF0 PREF1 PICO_STATUS PREF2 PREF3 (ps5000aGetTimebase)
	(
	   short											handle,
	   unsigned long							timebase,
	   long												noSamples,
	   long											* timeIntervalNanoseconds,
		 long											* maxSamples,
		 unsigned long							segmentIndex
	);

PREF0 PREF1 PICO_STATUS PREF2 PREF3 (ps5000aGetTimebase2)
	(
	   short											handle,
	   unsigned long							timebase,
	   long												noSamples,
	   float										* timeIntervalNanoseconds,
		 long											* maxSamples,
		 unsigned long							segmentIndex
	);

PREF0 PREF1 PICO_STATUS PREF2 PREF3 (ps5000aSetSigGenArbitrary)
	(
	 	short												handle,
	 	long												offsetVoltage,
	 	unsigned long								pkToPk,
	 	unsigned long								startDeltaPhase,
	 	unsigned long								stopDeltaPhase,
	 	unsigned long								deltaPhaseIncrement, 
	 	unsigned long								dwellCount,
	 	short											*	arbitraryWaveform, 
	 	long												arbitraryWaveformSize,
		PS5000A_SWEEP_TYPE					sweepType,
		PS5000A_EXTRA_OPERATIONS		operation,
		PS5000A_INDEX_MODE					indexMode,
		unsigned long								shots,
		unsigned long								sweeps,
		PS5000A_SIGGEN_TRIG_TYPE		triggerType,
		PS5000A_SIGGEN_TRIG_SOURCE	triggerSource,
		short												extInThreshold
	);

PREF0 PREF1 PICO_STATUS PREF2 PREF3(ps5000aSetSigGenBuiltIn)
	(
		short												handle,
		long												offsetVoltage,
		unsigned long								pkToPk,
		PS5000A_WAVE_TYPE						waveType,
		float												startFrequency,
		float												stopFrequency,
		float												increment,
		float												dwellTime,
		PS5000A_SWEEP_TYPE					sweepType,
		PS5000A_EXTRA_OPERATIONS		operation,
		unsigned long								shots,
		unsigned long								sweeps,
		PS5000A_SIGGEN_TRIG_TYPE		triggerType,
		PS5000A_SIGGEN_TRIG_SOURCE	triggerSource,
		short												extInThreshold
		);

PREF0 PREF1 PICO_STATUS PREF2 PREF3 (ps5000aSigGenSoftwareControl)
	(
		short												handle,
		short												state
	);

PREF0 PREF1 PICO_STATUS PREF2 PREF3 (ps5000aSetEts)
  (
		short												handle,
		PS5000A_ETS_MODE						mode,
		short												etsCycles,
		short												etsInterleave,
		long											* sampleTimePicoseconds
	);

PREF0 PREF1 PICO_STATUS PREF2 PREF3 (ps5000aSetTriggerChannelProperties)
	(
		short																				handle,
		PS5000A_TRIGGER_CHANNEL_PROPERTIES			 *	channelProperties,
		short																				nChannelProperties,
		short																				auxOutputEnable,
		long																				autoTriggerMilliseconds
	);

PREF0 PREF1 PICO_STATUS PREF2 PREF3 (ps5000aSetTriggerChannelConditions)
	(
		short													handle,
		PS5000A_TRIGGER_CONDITIONS	*	conditions,
		short													nConditions
	);

PREF0 PREF1 PICO_STATUS PREF2 PREF3 (ps5000aSetTriggerChannelDirections)
	(
		short													handle,
		PS5000A_THRESHOLD_DIRECTION		channelA,
		PS5000A_THRESHOLD_DIRECTION		channelB,
		PS5000A_THRESHOLD_DIRECTION		channelC,
		PS5000A_THRESHOLD_DIRECTION		channelD,
		PS5000A_THRESHOLD_DIRECTION		ext,
		PS5000A_THRESHOLD_DIRECTION		aux
	);

PREF0 PREF1 PICO_STATUS PREF2 PREF3 (ps5000aSetSimpleTrigger)
	(
		short												handle,
		short												enable,
		PS5000A_CHANNEL							source,
		short												threshold,
		PS5000A_THRESHOLD_DIRECTION direction,
		unsigned long								delay,
		short												autoTrigger_ms
	);

PREF0 PREF1 PICO_STATUS PREF2 PREF3 (ps5000aSetTriggerDelay)
	(
		short									handle,
		unsigned long					delay
	);

PREF0 PREF1 PICO_STATUS PREF2 PREF3 (ps5000aSetPulseWidthQualifier)
	(
		short														handle,
		PS5000A_PWQ_CONDITIONS				*	conditions,
		short														nConditions,
		PS5000A_THRESHOLD_DIRECTION			direction,
		unsigned long										lower,
		unsigned long										upper,
		PS5000A_PULSE_WIDTH_TYPE				type
	);

PREF0 PREF1 PICO_STATUS PREF2 PREF3 (ps5000aIsTriggerOrPulseWidthQualifierEnabled)
	(
		short 								handle,
		short 							* triggerEnabled,
		short 							* pulseWidthQualifierEnabled
	);

PREF0 PREF1 PICO_STATUS PREF2 PREF3 (ps5000aGetTriggerTimeOffset)
	(
		short									handle,
		unsigned long 			* timeUpper,
		unsigned long 			* timeLower,
		PS5000A_TIME_UNITS	*	timeUnits,
		unsigned long					segmentIndex	
	);


PREF0 PREF1 PICO_STATUS PREF2 PREF3 (ps5000aGetTriggerTimeOffset64)
	(
		short									handle,
		__int64							* time,
		PS5000A_TIME_UNITS	*	timeUnits,
		unsigned long				segmentIndex	
	);

PREF0 PREF1 PICO_STATUS PREF2 PREF3 (ps5000aGetValuesTriggerTimeOffsetBulk)
	(
	  short									handle,
		unsigned long				*	timesUpper,
		unsigned long				* timesLower,
		PS5000A_TIME_UNITS	*	timeUnits,
		unsigned long					fromSegmentIndex,
		unsigned long					toSegmentIndex
	);

PREF0 PREF1 PICO_STATUS PREF2 PREF3 (ps5000aGetValuesTriggerTimeOffsetBulk64)
	(
	  short									handle,
		__int64							*	times,
		PS5000A_TIME_UNITS	*	timeUnits,
		unsigned long					fromSegmentIndex,
		unsigned long					toSegmentIndex
	);

PREF0 PREF1 PICO_STATUS PREF2 PREF3 (ps5000aSetDataBuffers)
(
   short									handle,
	 PS5000A_CHANNEL 				channel,
	 short								*	bufferMax,
	 short								*	bufferMin,
   long										bufferLth,
	 unsigned long					segmentIndex,
	 PS5000A_RATIO_MODE			mode
);

PREF0 PREF1 PICO_STATUS PREF2 PREF3 (ps5000aSetDataBuffer)
(
   short								 handle,
	 PS5000A_CHANNEL 			 channel,
	 short							*  buffer,
   long									 bufferLth,
	 unsigned long				 segmentIndex,
	 PS5000A_RATIO_MODE		 mode
);

PREF0 PREF1 PICO_STATUS PREF2 PREF3 (ps5000aSetEtsTimeBuffer)
(
   short									handle,
	 __int64 *							buffer,
	 long										bufferLth
);

PREF0 PREF1 PICO_STATUS PREF2 PREF3 (ps5000aSetEtsTimeBuffers)
(
   short									handle,
	 unsigned long				* timeUpper,
	 unsigned long				* timeLower,
	 long										bufferLth
);

PREF0 PREF1 PICO_STATUS PREF2 PREF3 (ps5000aIsReady)
	(
		short handle,
		short * ready
	);

PREF0 PREF1 PICO_STATUS PREF2 PREF3 (ps5000aRunBlock)
	(
		short									handle,
		long									noOfPreTriggerSamples,
		long									noOfPostTriggerSamples,
		unsigned long					timebase,
		long								* timeIndisposedMs,
		unsigned long					segmentIndex,
		ps5000aBlockReady			lpReady,
		void								* pParameter
	);


PREF0 PREF1 PICO_STATUS PREF2 PREF3 (ps5000aRunStreaming)
  (
	  short									handle,
		unsigned long				* sampleInterval,	
		PS5000A_TIME_UNITS		sampleIntervalTimeUnits,
	  unsigned long					maxPreTriggerSamples,
	  unsigned long					maxPostTriggerSamples,
		short									autoStop,
		unsigned long					downSampleRatio,
		PS5000A_RATIO_MODE		downSampleRatioMode,
    unsigned long					overviewBufferSize
	);

PREF0 PREF1 PICO_STATUS PREF2 PREF3 (ps5000aGetStreamingLatestValues)
  (
    short									handle, 
    ps5000aStreamingReady	lpPs5000aReady,
		void								* pParameter
  );  

PREF0 PREF1 PICO_STATUS PREF2 PREF3 (ps5000aNoOfStreamingValues)
	(
	  short								handle,
		unsigned long			*	noOfValues
	);

PREF0 PREF1 PICO_STATUS PREF2 PREF3 (ps5000aGetMaxDownSampleRatio)
	(
	  short								handle,
		unsigned long 			noOfUnaggreatedSamples,
		unsigned long 		* maxDownSampleRatio,
		PS5000A_RATIO_MODE	downSampleRatioMode,
		unsigned long				segmentIndex
	);

PREF0 PREF1 PICO_STATUS PREF2 PREF3 (ps5000aGetValues)
	(
	  short								handle,
		unsigned long 			startIndex,
	  unsigned long			*	noOfSamples,
	  unsigned long				downSampleRatio,
		PS5000A_RATIO_MODE	downSampleRatioMode,
		unsigned long				segmentIndex,
		short							* overflow
	);

PREF0 PREF1 PICO_STATUS PREF2 PREF3 (ps5000aGetValuesAsync)
	(
	  short								handle,
		unsigned long				startIndex,
	  unsigned long				noOfSamples,
	  unsigned long				downSampleRatio,
		PS5000A_RATIO_MODE	downSampleRatioMode,
		unsigned long				segmentIndex,
	  void							*	lpDataReady,
		void							*	pParameter
	);

PREF0 PREF1 PICO_STATUS PREF2 PREF3 (ps5000aGetValuesBulk)
	(
	  short								handle,
		unsigned long			*	noOfSamples,
		unsigned long				fromSegmentIndex,
		unsigned long				toSegmentIndex,
	  unsigned long				downSampleRatio,
		PS5000A_RATIO_MODE 	downSampleRatioMode,
		short							* overflow
	);

PREF0 PREF1 PICO_STATUS PREF2 PREF3 (ps5000aGetValuesOverlapped)
	(
	  short										handle,
	  unsigned long			 			startIndex,
	  unsigned long					*	noOfSamples,
	  unsigned long						downSampleRatio,
	  PS5000A_RATIO_MODE			downSampleRatioMode,
		unsigned long						segmentIndex,
	  short									* overflow
	);


PREF0 PREF1 PICO_STATUS PREF2 PREF3 (ps5000aGetValuesOverlappedBulk)
	(
	  short									handle,
		unsigned long					startIndex,
  	unsigned long 	 		*	noOfSamples,
	  unsigned long					downSampleRatio,
	  PS5000A_RATIO_MODE		downSampleRatioMode,
	  unsigned long					fromSegmentIndex,
	  unsigned long					toSegmentIndex,
	  short								*	overflow
	);

PREF0 PREF1 PICO_STATUS PREF2 PREF3 (ps5000aEnumerateUnits)
	(
	short * count,
	char * serials,
	short * serialLth
	);

PREF0 PREF1 PICO_STATUS PREF2 PREF3 (ps5000aGetChannelInformation)
	(
	short										handle,
	PS5000A_CHANNEL_INFO		info,
	int											probe,
	int										* ranges,
	int										* length,
	int											channels);


PREF0 PREF1 PICO_STATUS PREF2 PREF3 (ps5000aMaximumValue)
	(
	short		handle,
	short * value
	);

PREF0 PREF1 PICO_STATUS PREF2 PREF3 (ps5000aMinimumValue)
	(
	short		handle,
	short * value
	);

PREF0 PREF1 PICO_STATUS PREF2 PREF3 (ps5000aGetAnalogueOffset)
	(
	short								handle, 
	PS5000A_RANGE				range,
	PS5000A_COUPLING		coupling,
	float							* maximumVoltage,
	float							* minimumVoltage
	);


PREF0 PREF1 PICO_STATUS PREF2 PREF3 (ps5000aGetMaxSegments)
	(
	short						handle,
	unsigned long * maxSegments
	);

PREF0 PREF1 PICO_STATUS PREF2 PREF3 (ps5000aChangePowerSource)
	(
	short				handle,
  PICO_STATUS powerState
	);

PREF0 PREF1 PICO_STATUS PREF2 PREF3 (ps5000aCurrentPowerSource)
	(
	short		handle
	);

PREF0 PREF1 PICO_STATUS PREF2 PREF3 (ps5000aStop)
	(
	  short handle
	);

PREF0 PREF1 PICO_STATUS PREF2 PREF3 (ps5000aPingUnit)
	(
	  short handle
	);

PREF0 PREF1 PICO_STATUS PREF2 PREF3 (ps5000aSetNoOfCaptures)
	(
	short					handle, 
	unsigned long nCaptures
	);

PREF0 PREF1 PICO_STATUS PREF2 PREF3 (ps5000aGetNoOfCaptures)
	(
	  short								handle,
		unsigned long			*	nCaptures
	);

PREF0 PREF1 PICO_STATUS PREF2 PREF3 (ps5000aGetNoOfProcessedCaptures)
	(
	  short								handle,
		unsigned long			*	nProcessedCaptures
	);

PREF0 PREF1 PICO_STATUS PREF2 PREF3 (ps5000aSetDeviceResolution)
	(
	  short											handle,
		PS5000A_DEVICE_RESOLUTION	resolution
	);

PREF0 PREF1 PICO_STATUS PREF2 PREF3 (ps5000aGetDeviceResolution)
	(
	  short												handle,
		PS5000A_DEVICE_RESOLUTION	*	resolution
	);

#endif
